@@ -1,17 +1,16 @@
 d <- as_messydate(c("2001-01-01", "2001-01", "2001",
                     "2001-01-01..2001-02-02", "{2001-10-01,2001-10-04}",
-                    "{2001-01,2001-02-02}", "28 BC", "-2000-01-01",
+                    "{2001-01,2001-02-02}", "-2000-01-01",
                     "2001-XX-01"))
 dd <- as_messydate(c("2001-01-01", "2001-01-01..2001-01-31",
                      "2001-01-01..2001-12-31",
                      "2001-01-01..2001-02-02", "{2001-10-01,2001-10-04}",
                      "{2001-01-01..2001-01-31,2001-02-02}",
-                     "-0028-01-01..-0028-12-31", "-2000-01-01",
+                     "-2000-01-01",
                      "2001-XX-01"))
 e <- expand(d)
 
 test_that("contract works properly", {
-  skip_on_os("linux")
   expect_equal(contract(e), d)
   expect_equal(contract(e, collapse = FALSE), dd)
 })
