@@ -1,17 +1,16 @@
 d <- as_messydate(c("2008-03-25", "-2012-02-27", "2001-01?", "2001",
                     "2001-01-01..2001-02-02", "{2001-01-01,2001-02-02}",
-                    "..2002-02-03", "2001-01-03..", "28 BC"))
+                    "..2002-02-03", "2001-01-03.."))
 a <- as_messydate(c("2008-03-28", "-2012-02-24", "2001-01-04..2001-02-03",
                     "2001-01-04..2002-01-03", "2001-01-04..2001-02-05",
                     "{2001-01-04,2001-02-05}", "..2002-02-06",
-                    "2001-01-06..", "-0027-12-29..-0028-12-28"))
+                    "2001-01-06.."))
 s <- as_messydate(c("2008-03-22", "-2012-03-01", "2000-12-29..2001-01-28",
                     "2000-12-29..2001-12-28", "2000-12-29..2001-01-30",
                     "{2000-12-29,2001-01-30} ", "..2002-01-31",
-                    "2000-12-31..", "-0028-01-04..-0029-01-03"))
+                    "2000-12-31.."))
 
 test_that("operations works properly", {
-  skip_on_os("linux")
   expect_equal(add(d, 3), a)
   expect_equal(d + 3, a)
   expect_equal(subtract(d, 3), s)
